@@ -1,4 +1,3 @@
+from .nodes import *
 from .learner import COINNLearner
-from .local import COINNLocal
 from .reducer import COINNReducer
-from .remote import COINNRemote
